@@ -19,7 +19,8 @@ if __name__ == "__main__":
       "What board do you want to use ?> "))]
 
   sg = crappy.blocks.Generator([{'type': 'sine', 'freq': .5, 'amplitude': 1,
-    'offset': .5, 'condition': 'delay=1000'}], cmd_label='cmd')
+                                 'offset': .5, 'condition': 'delay=1000'}],
+                               cmd_label='cmd')
 
   io = crappy.blocks.IOBlock(name, labels=['t(s)', 'chan0'],
                              cmd_labels=['cmd'], out_channels=0, verbose=True)
